Class: XBee::Frames::ATCommandQueueParameterValue
- Inherits:
-
ATCommand
- Object
- Frame
- IdentifiedFrame
- ATCommand
- XBee::Frames::ATCommandQueueParameterValue
- Defined in:
- lib/xbee/frames/at_command_queue_parameter_value.rb
Overview
This frame allows you to query or set device parameters. In contrast to the AT Command (0x08) frame, this frame queues new parameter values and does not apply them until you issue either:
* The AT Command (0x08) frame (for API type)
* The AC command
When querying parameter values, the 0x09 frame behaves identically to the 0x08 frame. The device returns register queries immediately and not does not queue them. The response for this command is also an AT Command Response frame (0x88).
Send a command to change the baud rate (BD) to 115200 baud, but do not apply changes yet. The module continues to operate at the previous baud rate until you apply the changes.
Instance Attribute Summary
Attributes inherited from ATCommand
#command_bytes, #parameter_bytes
Attributes inherited from IdentifiedFrame
Attributes inherited from Frame
Method Summary
Methods inherited from ATCommand
Methods inherited from IdentifiedFrame
Methods inherited from Frame
api_id, #bytes, from_packet, #initialize, #to_packet
Constructor Details
This class inherits a constructor from XBee::Frames::ATCommand